##  Import Data into Your Workspace
Your next step would be getting data into SAP LeanIX inventory. It is important to define a realistic and practical scope before starting out. Rather than aiming to gather everything at once, consider an iterative approach that aligns with your organization's situation and data management practices. Start by planning and mapping your existing data model to the SAP LeanIX data model. Deliberate on import strategies and decide when it is advantageous to use the 'Excel Import/Export' option versus other options such as SaaS Discovery. Consider how configuring your meta model fits into your workflow.
To get an overview of getting data into SAP LeanIX and to understand the steps, refer to [Getting Data into Your Workspace](https://help.sap.com/docs/leanix/ea/get-data-into-workspace?locale=en-US&state=PRODUCTION&version=CLOUD "Getting initial data into SAP LeanIX workspace.").
